==> connector-service-1.0.0-20191017.033313-64-sources.jar: com/bizvane/connectorservice/interfaces/rpc/IcrmConnectorServiceFeign.java <==
package com.bizvane.connectorservice.interfaces.rpc;

import com.bizvane.connectorservice.entity.Result;
import com.bizvane.connectorservice.entity.icrm.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import java.util.List;

/**
 * @author xiao.shu
 * @date 2019/10/15
 * @description
 */

@FeignClient(value = "${feign.client.connector.name}",path = "${feign.client.connector.path}/icrm")
public interface IcrmConnectorServiceFeign {


    /**
     *  商品档案类:获取客户信息
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "getDistributorList", method = RequestMethod.POST)
    Result<List<DistributorResponseVO>> getDistributorList(@RequestBody DistributorRequestVO requestVO);

    /**
     *  会员类:新增VIP卡，新增（修改）顾客资料
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addVip", method = RequestMethod.POST)
    Result<AddVipResponseVO> addVip(@RequestBody AddVipRequestVO requestVO);
    /**
     * 消费类:新增消费
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addConsume", method = RequestMethod.POST)
    Result addConsume(@RequestBody AddConsumeRequestVO requestVO);
    /**
     *  积分类:新增积分流水
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addIntegral", method = RequestMethod.POST)
    Result addIntegral(@RequestBody AddIntegralRequestVO requestVO);


}

==> connector-service-1.0.0-20191025.104806-77-sources.jar: com/bizvane/connectorservice/interfaces/rpc/IcrmConnectorServiceFeign.java <==
package com.bizvane.connectorservice.interfaces.rpc;

import com.bizvane.connectorservice.entity.Result;
import com.bizvane.connectorservice.entity.icrm.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import java.util.List;

/**
 * @author xiao.shu
 * @date 2019/10/15
 * @description
 */

@FeignClient(value = "${feign.client.connector.name}",path = "${feign.client.connector.path}/icrm")
public interface IcrmConnectorServiceFeign {


    /**
     *  商品档案类:获取客户信息
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "getDistributorList", method = RequestMethod.POST)
    Result<StoreResponseVO> getDistributorList(@RequestBody DistributorRequestVO requestVO);

    /**
     *  会员类:新增VIP卡，新增（修改）顾客资料
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addVip", method = RequestMethod.POST)
    Result<AddVipResponseVO> addVip(@RequestBody AddVipRequestVO requestVO);
    /**
     * 消费类:新增消费
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addConsume", method = RequestMethod.POST)
    Result addConsume(@RequestBody AddConsumeRequestVO requestVO);
    /**
     *  积分类:新增积分流水
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addIntegral", method = RequestMethod.POST)
    Result addIntegral(@RequestBody AddIntegralRequestVO requestVO);


}
